All Classes and Interfaces
Class
Description
Defines extractors that harvest arbitrary field data from a log record.
JDK logging handler implementation for forwarding logging data
to Fluentd.
Builder class used to provide configuration for the handler.
Analog of
Supplier, but enables throwing
an exception when producing objects.